bbprep.selectors.AllNonHSelector
================================

.. currentmodule:: bbprep.selectors

.. autoclass:: AllNonHSelector
   :members:

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~AllNonHSelector.select_atoms
   
   

   
   
   